@@ -37,6 +37,7 @@ def load_functions_from_file(repository, filename: str, required, optional=None,
         'repopath': RelocatePath(repository._filepath),
         'listify': lu.listify,
         'listrify': lu.listrify,
+        'uniquify': lu.uniquify,
 
         'FileReader': LocalFileReaderFactory(localpath),
         'ValidateException': le.LbuildValidateException,
@@ -278,11 +279,13 @@ class BaseNode(anytree.Node):
 
     @property
     def description(self):
-        return self._format_description(self, str(self._description))
+        return lu.with_forward_exception(self.fullname,
+                lambda: self._format_description(self, str(self._description)))
 
     @property
     def short_description(self):
-        return self._format_short_description(self, str(self._description))
+        return lu.with_forward_exception(self.fullname,
+                lambda: self._format_short_description(self, str(self._description)))
 
     @description.setter
     def description(self, description):
@@ -319,6 +322,10 @@ class BaseNode(anytree.Node):
     def module_resolver(self):
         return NameResolver(self, self.Type.MODULE)
 
+    @property
+    def filters(self):
+        return self._filters
+
     def render(self, filterfunc=None):
         return lbuild.format.format_node_tree(self, filterfunc)
 
